
#include "WiFi.h"

// Pin number
const uint8_t pinSW2 = 0;
const uint8_t pinSW3 = 4;
const uint8_t pinSW4 = 16;
const uint8_t pinSW5 = 5;
const uint8_t pinSDCS = 17;
const uint8_t pinSDA = 21;
const uint8_t pinSCL = 22;
const uint8_t pinPWM = 32;
const uint8_t pinLE = 13;
const uint8_t pinLoad = 33;
const uint8_t pinLED1 = 25;
const uint8_t pinLED2 = 26;
const uint8_t pinLED3 = 27;
const uint8_t pinLED4 = 14;
const uint8_t pinADC = 36;

RTC_DATA_ATTR uint16_t n = 0; // RTC_DATA_ATTRをつけるとDeepSleepをまたいで変数値を保持できます

void setup() {
  Serial.begin(115200);
  delay(10);
  Serial.print("\n\n-----------------------\n");
  Serial.print("Program Start\n");

  
  // Pin
  digitalWrite(pinLE, LOW);
  digitalWrite(pinLoad, HIGH);  // HIGH = OFF
  digitalWrite(pinLED1, HIGH);  // HIGH = OFF
  digitalWrite(pinLED2, HIGH);  // HIGH = OFF
  digitalWrite(pinLED3, HIGH);  // HIGH = OFF
  digitalWrite(pinLED4, HIGH);  // HIGH = OFF
  pinMode(pinLE, OUTPUT);
  pinMode(pinLoad, OUTPUT);
  pinMode(pinLED1, OUTPUT);
  pinMode(pinLED2, OUTPUT);
  pinMode(pinLED3, OUTPUT);
  pinMode(pinLED4, OUTPUT);
  pinMode(pinSW2, PULLUP);
  pinMode(pinSW3, PULLUP);
  pinMode(pinSW4, PULLUP);
  pinMode(pinSW5, PULLUP);
  ledcSetup(0, 3000, 8);
  ledcAttachPin(pinPWM, 0);

  WiFi.mode(WIFI_OFF);  // WiFiをOFFにすると動作中の電力を節約できます

  digitalWrite(pinLE, HIGH);  // ラッチICへの入力を有効にする
  digitalWrite(pinLoad, LOW); // 負荷接続 ラッチICによりDeepSleep中も保持されます (HIGHにすると負荷切断)
  digitalWrite(pinLED1, LOW); // LED1点灯 ラッチICによりDeepSleep中もほじされます
  digitalWrite(pinLE, LOW);   // ラッチICへの入力を無効にする

  // 何で起動したか取得
  esp_sleep_wakeup_cause_t wakeup_reason;
  wakeup_reason = esp_sleep_get_wakeup_cause();

  switch(wakeup_reason){
  case ESP_SLEEP_WAKEUP_EXT0:
    Serial.println("Wake up from DeepSleep by SW3");
    n++;
    Serial.print(n);
    Serial.println("times wake up from DeepSleep");
  case ESP_SLEEP_WAKEUP_EXT1:
    break;
  case ESP_SLEEP_WAKEUP_TIMER:
    Serial.println("Wake up from DeepSleep by Timer");
    n++;
    Serial.print(n);
    Serial.println("times wake up from DeepSleep");
    break;
  case ESP_SLEEP_WAKEUP_TOUCHPAD:
    break;
  case ESP_SLEEP_WAKEUP_ULP:
    break;
  default:
    Serial.println("Reset");
    break;
  }

  esp_sleep_enable_ext0_wakeup(GPIO_NUM_4, 0);  // SW3(IO4)が押されたらDeepSleepから復帰するように設定
  Serial.println("Start DeepSleep");
  ESP.deepSleep(30000000);  // 30秒タイマーのDeepSleep開始
}


void loop() {
  
}







